.. _variability-tutorial:

Low- and high-frequency variability quicklook (TBC)
---------------------------------------------------

.. Note ::

    For a general introduction to HENDRICS's workflow, please read the
    :ref:`quicklook-tutorial` tutorial

TBD
